@@ -689,7 +689,7 @@ _asn1_extract_der_octet (asn1_node node, const unsigned char *der,
       if (len2 < -1)
 	return ASN1_DER_ERROR;
 
-      if (len2 > 0)
+      if (len2 >= 0)
 	{
 	  DECR_LEN(der_len, len2+len3);
 	  _asn1_append_value (node, der + counter + len3, len2);
@@ -702,7 +702,7 @@ _asn1_extract_der_octet (asn1_node node, const unsigned char *der,
 				     der_len);
 	  if (result != ASN1_SUCCESS)
 	    return result;
-	  DECR_LEN(der_len, len2);
+	  len2 = 0;
 	}
 
       DECR_LEN(der_len, 1);
@@ -738,9 +738,6 @@ _asn1_get_octet_string (asn1_node node, const unsigned char *der, int der_len, i
 
       while (1)
 	{
-	  if (counter > der_len)
-	    return ASN1_DER_ERROR;
-
 	  if (indefinite == -1)
 	    {
 	      if (HAVE_TWO(der_len) && (der[counter] == 0) && (der[counter + 1] == 0))
